@@ -49,7 +49,7 @@ def authenticator(scope, request, *args, **kwargs):
 
 add_authenticator(authenticator)
 
-from baseweb.interface import register_component, register_static_folder
+from baseweb.interface import register_component, register_static_folder, register_external_script
 
 HERE       = os.path.dirname(__file__)
 COMPONENTS = os.path.join(HERE, "components")
@@ -60,5 +60,7 @@ register_component("app.js",        HERE)
 register_component("SourceView.js", COMPONENTS)
 register_component("logo.js",       COMPONENTS)
 
+register_external_script("https://www.google.com/recaptcha/api.js?render=6LcbsOEjAAAAAABrd1kwa0eciF8AZK2v6vSTxRzZ")
+
 from .pages            import index, page1, page2, page3, page4, page5
 from .pages.components import CollectionView, PageWithBanner
